@@ -31,7 +31,7 @@ class FilterBase(doing.DoerLapse):
         Wrapper for backwards compatibility to new ._initio signature
         """
         self._prepio(**ioinits)
-        return (None, odict())
+        return odict()
 
 
 class FilterSensorHeading(FilterBase):
